@@ -85,6 +85,8 @@ def filed(key,inquire=[]):
         'RoleId_user': DataManage.DataManage_Storage().RoleId_user,
         'mailUser': testMail.date().getMailUser,
         'mailPass': testMail.date().getMailPass,
+        'ADUser': testMail.date().getADUser,
+        'ADPass': testMail.date().getADPass,
         'm_id': arPort.inputs().createarPortId,
         'now_times': ParaDateFiledServer().now_time,
         'five_feature_times': ParaDateFiledServer().five_feature_time,
@@ -104,5 +106,5 @@ def filed(key,inquire=[]):
         return False
 
 if __name__ == '__main__':
-    date = filed("getSelfDatabasePassword")
+    date = filed("ADUser")
     print(date)
\ No newline at end of file
